require 'crowdfund/project'

module Crowdfund
  describe Project do

    before do
      $stdout = StringIO.new
      @initial_funds = 500
      @initial_minimum = 2000
      @initial_target = 5000
      @project = Project.new("XYZ", @initial_funds, @initial_minimum, @initial_target)
    end  

    it "Has an initial value of funds" do
      expect(@project.funds).to eq(@initial_funds)
    end

    it "has a string representation" do
      expect(@project.to_s).to eq("Project #{@project.name} has $#{@project.funds} towards a goal of $#{@project.target}")
    end

    it "has a total amount of fund still needed" do
      expect(@project.funding_still_needed).to eq(@initial_target - @initial_funds)

    end

    it "Increase the funding by 25 when adding fund" do
      @project.add_funds
      expect(@project.funds).to eq(@initial_funds + 25)

    end

    it "Decrease the funding by 15 when deleting fund" do
      @project.remove_funds
      expect(@project.funds).to eq(@initial_funds - 15)
    end

    context "Project with default parameter" do
      before do
        @project = Project.new("XYZ", 500, 1000)
      end

      it "Has an default funding of 0" do
        expect(@project.funds).to eq(0)
      end
    end

    context "Project with parameters of funded" do
      before do
        @project = Project.new("XYZ", 1000, 500, 1000)
      end

      it "is funded" do
        expect(@project).to be_fully_funded
      end
    end

    context "Project with parameters of not funded" do
      before do
        @project = Project.new("RYZ", 0, 100, 5000)
      end

      it "is not funded" do
        expect(@project).not_to be_fully_funded
      end

    end
  end
end